@@ -8,7 +8,7 @@ import threading
 from types import TracebackType
 from typing import Callable, Optional, Dict, Type
 
-from aio_pika import connect_robust, Message
+from aio_pika import connect_robust, Message, DeliveryMode
 from aio_pika.abc import (
     AbstractRobustConnection,
     AbstractChannel,
@@ -160,7 +160,9 @@ class BrokerInterface(threading.Thread):
     async def _send_message_to(self, queue_name: str, message: bytes) -> None:
         """Publish a message to a specific queue assuming the routing key equals the queue name."""
         logger.debug("Sending a message to %s containing: %s", queue_name, message)
-        await self._channel.default_exchange.publish(Message(body=message), routing_key=queue_name)
+        await self._channel.default_exchange.publish(
+            Message(body=message, delivery_mode=DeliveryMode.PERSISTENT), routing_key=queue_name
+        )
 
     async def _add_queue_subscription(
         self, queue_name: str, callback_on_message: Callable[[bytes], None]
@@ -291,9 +293,9 @@ class BrokerInterface(threading.Thread):
         )
         for queue_task in tasks_to_cancel:
             queue_task.cancel()
-        if self._channel:
+        if hasattr(self, "_channel") and self._channel:
             await self._channel.close()
-        if self._connection:
+        if hasattr(self, "_connection") and self._connection:
             await self._connection.close()
         logger.info("Stopped broker interface")
 
@@ -311,10 +313,17 @@ class BrokerInterface(threading.Thread):
         self._loop = asyncio.new_event_loop()
         asyncio.set_event_loop(self._loop)
 
+        setup_task = None
         try:
-            self._loop.create_task(self._setup_broker_interface())
+            setup_task = self._loop.create_task(self._setup_broker_interface())
             self._loop.run_forever()
         finally:
+            # Setup task is destroyed if no reference to the task is kept. This is just to check
+            # if the task was successful but also to keep the reference.
+            if setup_task and not setup_task.done():
+                logger.error("Setup task was not completed even though it was created.")
+            elif setup_task is None:
+                logger.error("Setup task for AMQP connection was not created.")
             self._loop.close()
 
     def add_queue_subscription(
